
dialogId("uts-m-otresy", "font_small", "My goodness, the impact created cave-in!")

dialogId("uts-v-projet0", "font_big", "I can’t go through this cave-in, we have to find another exit.")

dialogId("uts-v-projet1", "font_big", "This is not the way.")

dialogId("uts-v-sam", "font_big", "I won’t make it alone.")

dialogId("uts-m-lastura", "font_small", "I probably should have had lifted that shell first.")

dialogId("uts-v-poradi", "font_big", "Maybe we have to switch these objects.")

dialogId("uts-m-matrace", "font_small", "A mattress. The best thing you can get under water.")

dialogId("uts-m-snek", "font_small", "Now we can drop the snail on the mattress.")

dialogId("uts-m-nezvedneme", "font_small", "It will be difficult to pick up that snail from there.")

dialogId("uts-v-konecne", "font_big", "Finally, it’s there.")

dialogId("uts-m-chudak", "font_small", "The poor snail...")

dialogId("uts-v-koraly", "font_big", "We should search the coral reefs.")

dialogId("uts-m-tvorove", "font_small", "There are going to be many interesting beings to investigate there.")

dialogId("uts-v-mikroskop", "font_big", "Don’t we need a microscope to investigate corals?")

dialogId("uts-m-zivocich", "font_small", "Yes, they are small. But there can be other life forms.")

dialogId("uts-m-zelvy", "font_small", "Coral turtles, for example.")

dialogId("uts-m-batyskaf", "font_small", "And moreover I have a suspicion that there's a microscope in a bathyscaph.")
